==> Tagz-1.0.0.zip: Tagz/lang/it.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'parole',
 'L_TITLE'=>'Modifica le parole chiave del sito',
 'L_DESCRIPTION'=>'Gestisci i tag del sito. Elimina o rinomina la serie di parole chiave.',
#admin
 'L_CANCEL'=>'Annulla tutto',
 'L_DEVIENT'=>'diventa',
 'L_POUR'=>'per',
 'L_SEARCH'=>'Cerca negli articoli con questa parola chiave',
 'L_RESTORE'=>'ripristinare',
 'L_DEL'=>'cancellare',
 'L_RESTORE_ALL'=>'Ripristina tutti i campi lasciati vuoti',
 'L_DEL_ALL'=>'Cancella tutti i campi',
 'L_ART_NUM'=>'articolo / i con numero / i',
 'L_HELP_TAG_FIELD'=>'Se il campo è vuoto, elimina la parola chiave dopo il salvataggio.'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'rinfrescare',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'File Tags.xml aggiornato dalle parole chiave degli articoli',
 'L_TAG_PLACEHOLDER'=>'Cancellato se lasciato vuoto',
 'L_DEDUPLICATED'=>'deduplicati',
 'L_IN_REALITY'=>'In realtà',
 'L_IS_UNIK'=>'Unico (è solo)',
 'L_DOUBLES'=>'doppio',
 'L_TRIPLES'=>'triple',
 'L_QUADRUPLES'=>'quadruplo',
 'L_QUINTUPLES'=>'quintuplo',
 'L_SEXTUPLES'=>'sestuplo',
 'L_SEPTUPLES'=>'settuplo',
#config
 'L_ACCES'=>'Tipo (i) di account * autorizzato ad accedere al plugin',
 'L_HELP_ACCES'=>'Quali profili * sono autorizzati a utilizzare il plug-in. Elenco separato da virgole (Default PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Utente (i) non autorizzato ad accedere al plugin (menu nascosto)',
 'L_HELP_DENY'=>'Quali sono gli identificatori degli utenti a cui è vietato utilizzare il plugin. Elenco separato da virgola (ad esempio 001,002,007).'
);
?>

==> Tagz-1.0.4.zip: Tagz/lang/it.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'parole',
 'L_TITLE'=>'Modifica le parole chiave del sito',
 'L_DESCRIPTION'=>'Gestisci i tag del sito. Elimina o rinomina la serie di parole chiave.',
 'L_FILTER_TAGS'=>'Filtra parole chiave',
 'L_FILTER_TAGS_PH'=>'Filtro parole',
 'L_CANCEL'=>'Annulla tutto',
 'L_DEVIENT'=>'diventa',
 'L_POUR'=>'per',
 'L_SEARCH'=>'Cerca negli articoli con questa parola chiave',
 'L_RESTORE'=>'ripristinare',
 'L_DEL'=>'cancellare',
 'L_RESTORE_ALL'=>'Ripristina tutti i campi lasciati vuoti',
 'L_DEL_ALL'=>'Cancella tutti i campi',
 'L_ART_NUM'=>'articolo / i con numero / i',
 'L_HELP_TAG_FIELD'=>'Se il campo è vuoto, elimina la parola chiave dopo il salvataggio.',
 'L_HELP_TAG_CTRLZ'=>'La combinazione dei tasti Ctrl-z consente di annullare',
 'L_TAGS_REFRESH'=>'rinfrescare',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'File Tags.xml aggiornato dalle parole chiave degli articoli',
 'L_TAG_PLACEHOLDER'=>'Cancellato se lasciato vuoto',
 'L_DEDUPLICATED'=>'deduplicati',
 'L_IN_REALITY'=>'In realtà',
 'L_IS_UNIK'=>'Unico (è solo)',
 'L_DOUBLES'=>'doppio',
 'L_TRIPLES'=>'triple',
 'L_QUADRUPLES'=>'quadruplo',
 'L_QUINTUPLES'=>'quintuplo',
 'L_SEXTUPLES'=>'sestuplo',
 'L_SEPTUPLES'=>'settuplo',
 'L_OCTUPLES'=>'Octuple',
 'L_NONUPLES'=>'Non uples',
 'L_DECUPLES'=>'Dieci volte',
#config
 'L_ACCES'=>'Tipo (i) di account * autorizzato ad accedere al plugin',
 'L_HELP_ACCES'=>'Quali profili * sono autorizzati a utilizzare il plug-in. Elenco separato da virgole (Default PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Utente (i) non autorizzato ad accedere al plugin (menu nascosto)',
 'L_HELP_DENY'=>'Quali sono gli identificatori degli utenti a cui è vietato utilizzare il plugin. Elenco separato da virgola (ad esempio 001,002,007).',
);
?>
